@@ -6,7 +6,7 @@ lappend auto_path [file join [file dirname [info script]] .. lib]
 
                 puts "The following extensions are available:"
                 foreach {extension extensioninfo} [::teapotclient::get_extensions \
-                                                   [list teapot.activestate.com] \
+                                                   teapot.activestate.com \
                                                    {*} {*}] {
                         puts "  $extension [join $extensioninfo {, }]"
                 }
