@@ -12,7 +12,7 @@ SRCURL="http://sourceforge.net/projects/tls/files/tls/${VERS}/tls${VERS}-src.tar
 BUILDDIR="tls${VERS}"
 WORKDIR="${TMPDIR:-/tmp}/tls-$$${RANDOM}${RANDOM}${RANDOM}"
 PLATFORM="$(../platform)"
-PLATDIR="out/${PLATFORM}"
+PLATDIR="$(pwd)/out/${PLATFORM}"
 
 export VERS SRC SRCURL BUILDDIR WORKDIR PLATFORM PLATDIR
 
